@@ -460,10 +460,34 @@ int main(void)
 /*   rc = trio_sprintf(buffer, "%010.3e\n", 3141.5); */
 /*   Dump(buffer, rc); */
 
-  rc = trio_sprintf(buffer, "%e", 0.6);
-  Dump(buffer, rc);
-  rc = trio_sprintf(buffer, "%e", 0.5);
-  Dump(buffer, rc);
+/*   rc = trio_sprintf(buffer, "%e", 0.6); */
+/*   Dump(buffer, rc); */
+/*   rc = trio_sprintf(buffer, "%e", 0.5); */
+/*   Dump(buffer, rc); */
 
+/*   rc = trio_sprintf(buffer, "%#11.5g", 1e5); */
+/*   Dump(buffer, rc); */
+  
+/*   rc = trio_sprintf(buffer, "%010.3e", 3141.5); */
+/*   Dump(buffer, rc); */
+
+/*   rc = trio_sprintf(buffer, "%11.5g", 1e-5); */
+/*   Dump(buffer, rc); */
+
+/*   rc = trio_sprintf(buffer, "%g", 1.79769e+308); */
+/*   printf("%d \"%s\"\n", rc, buffer); */
+/*   trio_sscanf(buffer, "%g", &dnum); */
+/*   printf("%d %g\n", rc, dnum); */
+
+/*   rc = trio_snprintf(0, 0, "text"); */
+/*   Dump(buffer, rc); */
+
+  rc = trio_sprintf(buffer, "%.16.2f", (float)41.8713);
+  Dump(buffer, rc);
+  rc = trio_sprintf(buffer, "%.16.2f", (float)41.8687);
+  Dump(buffer, rc);
+  rc = trio_sprintf(buffer, "%.16.2f", (float)41.8684);
+  Dump(buffer, rc);
+  
   return 0;
 }
