@@ -43,7 +43,7 @@
 #define DOUBLE_EQUAL(x,y) (((x)>(y)-DBL_EPSILON) && ((x)<(y)+DBL_EPSILON))
 #define FLOAT_EQUAL(x,y) (((x)>(y)-FLT_EPSILON) && ((x)<(y)+FLT_EPSILON))
 
-static TRIO_CONST char rcsid[] = "@(#)$Id: regression.c,v 1.55 2006/01/24 19:32:32 breese Exp $";
+static TRIO_CONST char rcsid[] = "@(#)$Id: regression.c,v 1.59 2006/10/22 12:47:32 breese Exp $";
 
 #if defined(TRIO_EMBED_NAN)
 # include "trionan.c"
@@ -661,11 +661,13 @@ VerifyFormatting(TRIO_NOARGS)
       nerrors += Verify(__FILE__, __LINE__, "Pointer 0x01234567",
 			"Pointer %p", 0x1234567);
     }
+#if defined(TRIO_COMPILER_SUPPORTS_LL)
   else if (sizeof(void *) == 8)
     {
       nerrors += Verify(__FILE__, __LINE__, "Pointer 0x0123456789012345",
-			"Pointer %p", 0x123456789012345);
+			"Pointer %p", 0x123456789012345LL);
     }
+#endif
   /* Nil pointer */
   nerrors += Verify(__FILE__, __LINE__, "Pointer (nil)",
 		   "Pointer %p", NULL);
@@ -704,8 +706,18 @@ VerifyFormatting(TRIO_NOARGS)
 
 #if TRIO_FEATURE_ERRNO
   errno = EINTR;
+# if defined(TRIO_PLATFORM_LYNX)
+#  if defined(PREDEF_STANDARD_POSIX_1996)
+  nerrors += Verify(__FILE__, __LINE__, "Interrupted system call ",
+		    "%m");
+#  else
+  nerrors += Verify(__FILE__, __LINE__, "System call interrupted",
+		    "%m");
+#  endif
+# else
   nerrors += Verify(__FILE__, __LINE__, "Interrupted system call",
 		    "%m");
+# endif
 #endif
   
 #if TRIO_FEATURE_QUAD
@@ -866,7 +878,7 @@ VerifyErrors(TRIO_NOARGS)
   /* Error: Invalid argument 2 */
   rc = trio_snprintf(buffer, sizeof(buffer), "%#");
 #if TRIO_FEATURE_ERRORCODE
-# if TRIO_FEATRUE_STRERR
+# if TRIO_FEATURE_STRERR
   trio_snprintf(buffer, sizeof(buffer), "Err = %d (%s), Pos = %d",
 		TRIO_ERROR_CODE(rc),
 		TRIO_ERROR_NAME(rc),
@@ -887,7 +899,7 @@ VerifyErrors(TRIO_NOARGS)
   /* Error: Invalid argument 3 */
   rc = trio_snprintf(buffer, sizeof(buffer), "%hhhd", 42);
 #if TRIO_FEATURE_ERRORCODE
-# if TRIO_FEATRUE_STRERR
+# if TRIO_FEATURE_STRERR
   trio_snprintf(buffer, sizeof(buffer), "Err = %d (%s), Pos = %d",
 		TRIO_ERROR_CODE(rc),
 		TRIO_ERROR_NAME(rc),
@@ -908,7 +920,7 @@ VerifyErrors(TRIO_NOARGS)
   /* Error: Double reference */
   rc = trio_snprintf(buffer, sizeof(buffer), "hello %1$d %1$d", 31, 32);
 #if TRIO_FEATURE_ERRORCODE
-# if TRIO_FEATRUE_STRERR
+# if TRIO_FEATURE_STRERR
   trio_snprintf(buffer, sizeof(buffer), "Err = %d (%s), Pos = %d",
 		TRIO_ERROR_CODE(rc),
 		TRIO_ERROR_NAME(rc),
@@ -939,7 +951,7 @@ VerifyErrors(TRIO_NOARGS)
   /* Error: Reference gap */
   rc = trio_snprintf(buffer, sizeof(buffer), "%3$d %1$d", 31, 32, 33);
 #if TRIO_FEATURE_ERRORCODE
-# if TRIO_FEATRUE_STRERR
+# if TRIO_FEATURE_STRERR
   trio_snprintf(buffer, sizeof(buffer), "Err = %d (%s), Pos = %d",
 		TRIO_ERROR_CODE(rc),
 		TRIO_ERROR_NAME(rc),
@@ -1027,6 +1039,23 @@ VerifyScanningIntegers(TRIO_NOARGS)
 #if TRIO_FEATURE_SCANF
 int
 VerifyScanningOneFloat
+TRIO_ARGS5((file, line, expected, format, original),
+	   TRIO_CONST char *file,
+	   int line,
+	   TRIO_CONST char *expected,
+	   TRIO_CONST char *format,
+	   double original)
+{
+  float number;
+  char data[512];
+  
+  trio_snprintf(data, sizeof(data), format, original);
+  trio_sscanf(data, format, &number);
+  return Verify(file, line, expected, format, number);
+}
+
+int
+VerifyScanningOneDouble
 TRIO_ARGS5((file, line, expected, format, original),
 	   TRIO_CONST char *file,
 	   int line,
@@ -1084,8 +1113,8 @@ VerifyScanningFloats(TRIO_NOARGS)
   nerrors += VerifyScanningOneFloat(__FILE__, __LINE__, "0X1.2D687P+20",
 				      "%A", 1234567.0);
 # endif
-  nerrors += VerifyScanningOneFloat(__FILE__, __LINE__, "1.79769e+308",
-				      "%g", 1.79769e+308);
+  nerrors += VerifyScanningOneDouble(__FILE__, __LINE__, "1.79769e+308",
+				      "%lg", 1.79769e+308);
   nerrors += VerifyScanningOneFloat(__FILE__, __LINE__, "nan",
 				      "%f", trio_nan());
   nerrors += VerifyScanningOneFloat(__FILE__, __LINE__, "NAN",
@@ -1163,7 +1192,7 @@ VerifyScanningRegression(TRIO_NOARGS)
   int nerrors = 0;
   int rc;
 #if TRIO_FEATURE_FLOAT
-  int index;
+  int offset;
   double dnumber;
 # if defined(TRIO_BREESE)
   trio_long_double_t ldnumber;
@@ -1174,9 +1203,9 @@ VerifyScanningRegression(TRIO_NOARGS)
   char ch;
 
 #if TRIO_FEATURE_FLOAT
-  rc = trio_sscanf("1.5", "%lf%n", &dnumber, &index);
+  rc = trio_sscanf("1.5", "%lf%n", &dnumber, &offset);
   nerrors += Verify(__FILE__, __LINE__, "1 3 1.500000",
-		    "%d %d %f", rc, index, dnumber);
+		    "%d %d %f", rc, offset, dnumber);
 #endif
   rc = trio_sscanf("q 123", "%c%ld", &ch, &lnumber);
   nerrors += Verify(__FILE__, __LINE__, "q 123",
@@ -1205,10 +1234,10 @@ VerifyScanningRegression(TRIO_NOARGS)
 # endif
 #endif
 #if TRIO_FEATURE_FLOAT
-  rc = trio_sscanf("1.e-6", "%g", &dnumber);
+  rc = trio_sscanf("1.e-6", "%lg", &dnumber);
   nerrors += Verify(__FILE__, __LINE__, "1e-06",
 		    "%g", dnumber);
-  rc = trio_sscanf("1e-6", "%g", &dnumber);
+  rc = trio_sscanf("1e-6", "%lg", &dnumber);
   nerrors += Verify(__FILE__, __LINE__, "1e-06",
 		    "%g", dnumber);
 #endif
